@@ -1,10 +1,10 @@
-/* HSV color selector for GTK+
+/* HSV color selector for GTK
  *
  * Copyright (C) 1999 The Free Software Foundation
  *
  * Authors: Simon Budig <Simon.Budig@unix-ag.org> (original code)
- *          Federico Mena-Quintero <federico@gimp.org> (cleanup for GTK+)
- *          Jonathan Blandford <jrb@redhat.com> (cleanup for GTK+)
+ *          Federico Mena-Quintero <federico@gimp.org> (cleanup for GTK)
+ *          Jonathan Blandford <jrb@redhat.com> (cleanup for GTK)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,19 +21,16 @@
  */
 
 /*
- * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
- * file for a list of people on the GTK+ Team.  See the ChangeLog
+ * Modified by the GTK Team and others 1997-2000.  See the AUTHORS
+ * file for a list of people on the GTK Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
+ * GTK at ftp://ftp.gtk.org/pub/gtk/.
  *
  * Updated and adapted for inclusion in Gcolor3 by Jente Hidskes 2018
  */
 
 #include "config.h"
 
-// TODO: get rid of all deprecated API
-#define GDK_DISABLE_DEPRECATION_WARNINGS
-
 #include "gcolor3-hsv.h"
 
 #include <math.h>
@@ -41,8 +38,6 @@
 
 #include <gtk/gtk.h>
 
-#define I_(string) g_intern_static_string (string)
-
 /**
  * SECTION:gtkhsv
  * @Short_description: A “color wheel” widget
@@ -161,7 +156,7 @@ gcolor3_hsv_class_init (Gcolor3HSVClass *class)
   hsv_class->move = gcolor3_hsv_move;
 
   hsv_signals[CHANGED] =
-    g_signal_new (I_("changed"),
+    g_signal_new ("changed",
                   G_OBJECT_CLASS_TYPE (gobject_class),
                   G_SIGNAL_RUN_FIRST,
                   G_STRUCT_OFFSET (Gcolor3HSVClass, changed),
@@ -170,7 +165,7 @@ gcolor3_hsv_class_init (Gcolor3HSVClass *class)
                   G_TYPE_NONE, 0);
 
   hsv_signals[MOVE] =
-    g_signal_new (I_("move"),
+    g_signal_new ("move",
                   G_OBJECT_CLASS_TYPE (gobject_class),
                   G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
                   G_STRUCT_OFFSET (Gcolor3HSVClass, move),
@@ -614,15 +609,14 @@ set_cross_grab (Gcolor3HSV *hsv,
 
   cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (hsv)),
                                        GDK_CROSSHAIR);
-  gdk_device_grab (device,
-                   priv->window,
-                   GDK_OWNERSHIP_NONE,
-                   FALSE,
-                   GDK_POINTER_MOTION_MASK
-                    | GDK_POINTER_MOTION_HINT_MASK
-                    | GDK_BUTTON_RELEASE_MASK,
-                   cursor,
-                   time);
+  gdk_seat_grab (gdk_device_get_seat (device),
+                 priv->window,
+                 GDK_SEAT_CAPABILITY_ALL_POINTING,
+                 FALSE,
+                 cursor,
+                 NULL,
+                 NULL,
+                 NULL);
   g_object_unref (cursor);
 }
 
@@ -724,7 +718,7 @@ gcolor3_hsv_button_release (GtkWidget      *widget,
       g_assert_not_reached ();
     }
 
-  gdk_device_ungrab (gdk_event_get_device ((GdkEvent *) event), event->time);
+  gdk_seat_ungrab (gdk_device_get_seat (gdk_event_get_device ((GdkEvent *) event)));
 
   return TRUE;
 }
